# edprompt
python shell edit 🤣🤣🤣

*`pip install edprompt`*

# how 2 use?

```python
>>> import edprompt
>>>
>>> "buy me a beer"
>>> -y
save as : but_nobody.txt
>>>
```

# deps
[funny](https://pypi.org/clro)
